@@ -69,6 +69,8 @@ class AddVPNServiceAction(workflows.Action):
                               _('Unable to retrieve routers list.'))
             routers = []
         for r in routers:
+            if not r.external_gateway_info:
+                continue
             router_id_choices.append((r.id, r.name))
         self.fields['router_id'].choices = router_id_choices
         return router_id_choices
@@ -147,7 +149,7 @@ class AddEndpointGroupAction(workflows.Action):
     subnets = forms.MultipleChoiceField(
         required=False,
         label=_("Local System Subnets"),
-        widget=forms.ThemableCheckboxSelectMultiple(attrs={
+        widget=forms.CheckboxSelectMultiple(attrs={
             'class': 'switched',
             'data-switch-on': 'type',
             'data-type-subnet': _("External System Subnets"),
@@ -197,8 +199,8 @@ class AddEndpointGroup(workflows.Workflow):
     slug = "addendpointgroup"
     name = _("Add Endpoint Group")
     finalize_button_name = _("Add")
-    success_message = _('Added Endpoint Group "%s".')
-    failure_message = _('Unable to add Endpoint Group "%s".')
+    success_message = _('Added endpoint group "%s".')
+    failure_message = _('Unable to add endpoint group "%s".')
     success_url = "horizon:project:vpn:index"
     default_steps = (AddEndpointGroupStep,)
 
@@ -431,7 +433,7 @@ class AddIPsecSiteConnectionAction(workflows.Action):
         label=_("VPN service associated with this connection"))
     local_ep_group_id = forms.ThemableChoiceField(
         required=False,
-        label=_("Endpoint Group for local subnet(s)"),
+        label=_("Endpoint group for local subnet(s)"),
         help_text=_("Local subnets which the new IPsec connection is "
                     "connected to. Required if no subnet is specified "
                     "in a VPN service selected."))
@@ -449,7 +451,7 @@ class AddIPsecSiteConnectionAction(workflows.Action):
                     "Can be IPv4/IPv6 address, e-mail, key ID, or FQDN"),)
     peer_ep_group_id = forms.ThemableChoiceField(
         required=False,
-        label=_("Endpoint Group for remote peer CIDR(s)"),
+        label=_("Endpoint group for remote peer CIDR(s)"),
         help_text=_("Remote peer CIDR(s) connected to the new IPsec "
                     "connection."))
     peer_cidrs = forms.MultiIPField(
